@@ -19,7 +19,7 @@ use Module::Install::Base;
               &get_bzip2_version
             );
 
-$VERSION = sprintf "%d.%02d%02d", q/0.30.6/ =~ /(\d+)/g;
+$VERSION = sprintf "%d.%02d%02d", q/0.30.7/ =~ /(\d+)/g;
 
 # ---------------------------------------------------------------------------
 
@@ -200,7 +200,7 @@ sub _prompt_user_for_program_locations
 
     my $choice = $self->prompt(
       "Where can I find your \"$program_name\" executable?" .
-      "$allowed_types" => $full_path);
+      "$allowed_types", $full_path);
 
     $program_info{$program_name} =
       { path => undef, type => undef, version => undef }, next
@@ -360,7 +360,6 @@ sub _Make_Absolute
 
 sub get_gnu_version
 {
-  my $self = shift;
   my $program = shift;
 
   die "Missing GNU program to get version for" unless defined $program;
@@ -392,7 +391,6 @@ sub get_gnu_version
 
 sub get_bzip2_version
 {
-  my $self = shift;
   my $program = shift;
 
   my $command = "$program --help 2>&1 1>" . File::Spec->devnull();
@@ -617,9 +615,8 @@ Gets the version of bzip2.
 
 =head1 LICENSE
 
-This code is distributed under the GNU General Public License (GPL). See the
-file LICENSE in the distribution, http://www.opensource.org/gpl-license.html,
-and http://www.opensource.org/.
+This code is distributed under the GNU General Public License (GPL) Version 2.
+See the file LICENSE in the distribution for details.
 
 =head1 AUTHOR
 
